==> PGCup_2002_08_06.tar.gz: PGCup/sources/components/table/ColumnPanelToolbar.java <==
/*
 * ColumnPanelToolbar.java
 *
 * Created on 1 de agosto de 2002, 16:35
 */

package components.table;
import components.*;
import javax.swing.*;
import java.awt.event.*;

/**
 *
 * @author  nestor
 */
public class ColumnPanelToolbar extends JToolBar {
    ColumnPanel panel = null;
    JButton sort = null;
    JButton newRecord = null;
    JButton editRecord = null;
    JButton deleteRecord = null;
    
    /** Creates a new instance of ColumnPanelToolbar */
    public ColumnPanelToolbar(ColumnPanel _panel) {
        panel = _panel;
        
        newRecord = new JButton(new ImageIcon("images/new.png"));
        newRecord.setActionCommand(ColumnPanelListener.AC_NEW);
        newRecord.setToolTipText("New Column");
        newRecord.addActionListener(panel.getListener());
        this.add(newRecord);
        editRecord = new JButton(new ImageIcon("images/edit.png"));
        editRecord.setActionCommand(ColumnPanelListener.AC_EDIT);
        editRecord.setToolTipText("Edit Column");
        editRecord.addActionListener(panel.getListener());
        this.add(editRecord);
        deleteRecord = new JButton(new ImageIcon("images/delete.png"));
        deleteRecord.setActionCommand(ColumnPanelListener.AC_DELETE);
        deleteRecord.setToolTipText("Delete Column");
        deleteRecord.addActionListener(panel.getListener());
        this.add(deleteRecord);
        
        this.add(Box.createHorizontalGlue());
    }
    
    public void refreshValidation(){
        if(panel.getTable() != null){
            boolean valid = panel.getTable() != null;
            sort.setEnabled(valid);
            newRecord.setEnabled(valid);
            editRecord.setEnabled(valid);
            deleteRecord.setEnabled(valid);
        }
    }
}

==> PGCup_2002_08_08.tar.gz: PGCup/sources/components/table/ColumnPanelToolbar.java <==
/*
 * ColumnPanelToolbar.java
 *
 * Created on 1 de agosto de 2002, 16:35
 */

package components.table;
import components.*;
import javax.swing.*;
import java.awt.event.*;

/**
 *
 * @author  nestor
 */
public class ColumnPanelToolbar extends JToolBar {
    ColumnPanel panel = null;
    JButton sort = null;
    JButton newRecord = null;
    JButton editRecord = null;
    JButton deleteRecord = null;
    
    /** Creates a new instance of ColumnPanelToolbar */
    public ColumnPanelToolbar(ColumnPanel _panel) {
        panel = _panel;
        
        newRecord = new JButton(new ImageIcon(getClass().getResource("/images/new.png")));
        newRecord.setActionCommand(ColumnPanelListener.AC_NEW);
        newRecord.setToolTipText("New Column");
        newRecord.addActionListener(panel.getListener());
        this.add(newRecord);
        editRecord = new JButton(new ImageIcon(getClass().getResource("/images/edit.png")));
        editRecord.setActionCommand(ColumnPanelListener.AC_EDIT);
        editRecord.setToolTipText("Edit Column");
        editRecord.addActionListener(panel.getListener());
        this.add(editRecord);
        deleteRecord = new JButton(new ImageIcon(getClass().getResource("/images/delete.png")));
        deleteRecord.setActionCommand(ColumnPanelListener.AC_DELETE);
        deleteRecord.setToolTipText("Delete Column");
        deleteRecord.addActionListener(panel.getListener());
        this.add(deleteRecord);
        
        this.add(Box.createHorizontalGlue());
    }
    
    public void refreshValidation(){
        if(panel.getTable() != null){
            boolean valid = panel.getTable() != null;
            sort.setEnabled(valid);
            newRecord.setEnabled(valid);
            editRecord.setEnabled(valid);
            deleteRecord.setEnabled(valid);
        }
    }
}
